==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaJzx.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.id;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 界址线信息
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(name = "ba_jzx")
public class BaJzx implements Serializable {

    @XmlAttribute
    private int bsm;

    @XmlAttribute
    private String zdzhdm;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String jzxcd;

    @XmlAttribute
    private String jzxlb;

    @XmlAttribute
    private String jzxwz;

    @XmlAttribute
    private String jxxz;

    @XmlAttribute
    @Nullable
    private String qsjxxysbh;

    @XmlAttribute
    @Nullable
    private String qsjxxys;

    @XmlAttribute
    @Nullable
    private String qszyyysbh;

    @XmlAttribute
    @Nullable
    private String qszyyys;

    @XmlAttribute
    @Id
    @id
    private String id;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    private String qxdm;

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public int getBsm() {
        return bsm;
    }

    public void setBsm(int bsm) {
        this.bsm = bsm;
    }

    public String getZdzhdm() {
        return zdzhdm;
    }

    public void setZdzhdm(String zdzhdm) {
        this.zdzhdm = zdzhdm;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getJzxcd() {
        return jzxcd;
    }

    public void setJzxcd(String jzxcd) {
        this.jzxcd = jzxcd;
    }

    public String getJzxlb() {
        return jzxlb;
    }

    public void setJzxlb(String jzxlb) {
        this.jzxlb = jzxlb;
    }

    public String getJzxwz() {
        return jzxwz;
    }

    public void setJzxwz(String jzxwz) {
        this.jzxwz = jzxwz;
    }

    public String getJxxz() {
        return jxxz;
    }

    public void setJxxz(String jxxz) {
        this.jxxz = jxxz;
    }

    public String getQsjxxysbh() {
        return qsjxxysbh;
    }

    public void setQsjxxysbh(String qsjxxysbh) {
        this.qsjxxysbh = qsjxxysbh;
    }

    public String getQsjxxys() {
        return qsjxxys;
    }

    public void setQsjxxys(String qsjxxys) {
        this.qsjxxys = qsjxxys;
    }

    public String getQszyyysbh() {
        return qszyyysbh;
    }

    public void setQszyyysbh(String qszyyysbh) {
        this.qszyyysbh = qszyyysbh;
    }

    public String getQszyyys() {
        return qszyyys;
    }

    public void setQszyyys(String qszyyys) {
        this.qszyyys = qszyyys;
    }
}

==> realestate-supervise-common-1.1.0-20251204.013828-71-sources.jar: cn/gtmap/realestate/supervise/entity/BaJzx.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.jgbsm;
import cn.gtmap.realestate.supervise.core.reflect.id;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 界址线信息
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(name = "ba_jzx")
public class BaJzx implements Serializable {

    @XmlAttribute
    private int bsm;

    @XmlAttribute
    private String zdzhdm;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String jzxcd;

    @XmlAttribute
    private String jzxlb;

    @XmlAttribute
    private String jzxwz;

    @XmlAttribute
    private String jxxz;

    @XmlAttribute
    @Nullable
    private String qsjxxysbh;

    @XmlAttribute
    @Nullable
    private String qsjxxys;

    @XmlAttribute
    @Nullable
    private String qszyyysbh;

    @XmlAttribute
    @Nullable
    private String qszyyys;

    @XmlAttribute
    @Id
    @id
    private String id;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    private String qxdm;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段开始===============

    /** 宗地/宗海代码1 */
    @XmlAttribute
    private String zdzhdm1;

    /** 宗地/宗海代码2 */
    @XmlAttribute
    private String zdzhdm2;

    /** 界址线走向说明 */
    @XmlAttribute
    private String jzxzxsm;

    /** 权属界线协议书附图 */
    @XmlAttribute
    private String qsjxxysft;

    /** 界址说明表 */
    @XmlAttribute
    private String jzsmb;

    /** 原宗地/宗海代码 */
    @XmlAttribute
    private String yzdzhdm;

    /** 备注 */
    @XmlAttribute
    private String bz;

    /** 监管标识码 */
    @jgbsm
    private String jgbsf;

    /** 登记状态 */
    @XmlAttribute
    private String djzt;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段结束===============

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public int getBsm() {
        return bsm;
    }

    public void setBsm(int bsm) {
        this.bsm = bsm;
    }

    public String getZdzhdm() {
        return zdzhdm;
    }

    public void setZdzhdm(String zdzhdm) {
        this.zdzhdm = zdzhdm;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getJzxcd() {
        return jzxcd;
    }

    public void setJzxcd(String jzxcd) {
        this.jzxcd = jzxcd;
    }

    public String getJzxlb() {
        return jzxlb;
    }

    public void setJzxlb(String jzxlb) {
        this.jzxlb = jzxlb;
    }

    public String getJzxwz() {
        return jzxwz;
    }

    public void setJzxwz(String jzxwz) {
        this.jzxwz = jzxwz;
    }

    public String getJxxz() {
        return jxxz;
    }

    public void setJxxz(String jxxz) {
        this.jxxz = jxxz;
    }

    public String getQsjxxysbh() {
        return qsjxxysbh;
    }

    public void setQsjxxysbh(String qsjxxysbh) {
        this.qsjxxysbh = qsjxxysbh;
    }

    public String getQsjxxys() {
        return qsjxxys;
    }

    public void setQsjxxys(String qsjxxys) {
        this.qsjxxys = qsjxxys;
    }

    public String getQszyyysbh() {
        return qszyyysbh;
    }

    public void setQszyyysbh(String qszyyysbh) {
        this.qszyyysbh = qszyyysbh;
    }

    public String getQszyyys() {
        return qszyyys;
    }

    public void setQszyyys(String qszyyys) {
        this.qszyyys = qszyyys;
    }

    public String getZdzhdm1() {
        return zdzhdm1;
    }

    public void setZdzhdm1(String zdzhdm1) {
        this.zdzhdm1 = zdzhdm1;
    }

    public String getZdzhdm2() {
        return zdzhdm2;
    }

    public void setZdzhdm2(String zdzhdm2) {
        this.zdzhdm2 = zdzhdm2;
    }

    public String getJzxzxsm() {
        return jzxzxsm;
    }

    public void setJzxzxsm(String jzxzxsm) {
        this.jzxzxsm = jzxzxsm;
    }

    public String getQsjxxysft() {
        return qsjxxysft;
    }

    public void setQsjxxysft(String qsjxxysft) {
        this.qsjxxysft = qsjxxysft;
    }

    public String getJzsmb() {
        return jzsmb;
    }

    public void setJzsmb(String jzsmb) {
        this.jzsmb = jzsmb;
    }

    public String getYzdzhdm() {
        return yzdzhdm;
    }

    public void setYzdzhdm(String yzdzhdm) {
        this.yzdzhdm = yzdzhdm;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getJgbsf() {
        return jgbsf;
    }

    public void setJgbsf(String jgbsf) {
        this.jgbsf = jgbsf;
    }

    public String getDjzt() {
        return djzt;
    }

    public void setDjzt(String djzt) {
        this.djzt = djzt;
    }
}
